@@ -3,7 +3,7 @@ package Function::Return;
 use v5.14.0;
 use warnings;
 
-our $VERSION = "0.06";
+our $VERSION = "0.07";
 
 use attributes ();
 use Sub::Util ();
@@ -13,28 +13,38 @@ use Scope::Upper ();
 use B::Hooks::EndOfScope;
 use Function::Parameters;
 
-my $ATTR_NAME = 'Return';
+use constant DEFAULT_NO_CHECK => !!($ENV{FUNCTION_RETURN_NO_CHECK} // 0);
 
+my %ATTR;
 my %NO_CHECK;
+my @DECLARATIONS;
+
 sub import {
     my $pkg = caller;
     my $class = shift;
     my %args = @_;
 
     $pkg = $args{pkg} ? $args{pkg} : $pkg;
-    $NO_CHECK{$pkg} = exists $args{no_check} ? !!$args{no_check} : !!0;
+    $NO_CHECK{$pkg} = exists $args{no_check} ? !!$args{no_check} : DEFAULT_NO_CHECK;
 
     no strict qw(refs);
     *{"${pkg}::FETCH_CODE_ATTRIBUTES"} = \&_FETCH_CODE_ATTRIBUTES;
     *{"${pkg}::MODIFY_CODE_ATTRIBUTES"} = \&_MODIFY_CODE_ATTRIBUTES;
 
     on_scope_end {
-        _check_sub();
+        while (my $decl = shift @DECLARATIONS) {
+            my ($pkg, $sub, $types) = @$decl{qw(pkg sub types)};
+
+            if (no_check($pkg)) {
+                _register_return_info($sub, $types);
+                next;
+            }
+
+            _register_wrapped_sub($pkg, $sub, $types);
+        }
     }
 }
 
-my %ATTR;
-my @DECLARATIONS;
 sub _FETCH_CODE_ATTRIBUTES {
     my ($pkg, $sub, @attrs) = @_;
     return @{$ATTR{$sub}||[]};
@@ -62,7 +72,7 @@ sub _MODIFY_CODE_ATTRIBUTES {
 sub _attr_re {
     return qr!
         ^
-        $ATTR_NAME
+        Return
         \((.*?)\)
         $
     !x;
@@ -133,10 +143,20 @@ sub _get_parameters_info {
     return Function::Parameters::info($sub);
 }
 
+sub _delete_parameters_info {
+    my ($key) = @_;
+    delete $Function::Parameters::metadata{$key};
+}
+
+sub _key_parameters_info {
+    my ($sub) = @_;
+    return Function::Parameters::_cv_root($sub);
+}
+
 sub _set_parameters_info {
     my ($info, $sub) = @_;
 
-    my $key = Function::Parameters::_cv_root($sub);
+    my $key = _key_parameters_info($sub);
     return Function::Parameters::_register_info(
         $key,
         $info->keyword,
@@ -176,35 +196,34 @@ sub _register_return_info {
     $metadata{$key} = $info;
 }
 
-sub _check_sub {
-    for my $decl (@DECLARATIONS) {
-        my ($pkg, $sub, $types)  = @$decl{qw(pkg sub types)};
+sub _register_wrapped_sub {
+    my ($pkg, $sub, $types) = @_;
 
-        if (no_check($pkg)) {
-            _register_return_info($sub, $types);
-            next;
-        }
+    my $subname   = Sub::Util::subname($sub);
+    my $prototype = Sub::Util::prototype($sub);
+    my @attr      = attributes::get($sub);
+    my $pinfo     = _get_parameters_info($sub);
+    my $pkey      = _key_parameters_info($sub);
 
-        my $subname   = Sub::Util::subname($sub);
-        my $prototype = Sub::Util::prototype($sub);
-        my @attr      = attributes::get($sub);
-        my $pinfo     = _get_parameters_info($sub);
+    my $wrapped = __PACKAGE__->wrap_sub($sub, $types);
 
-        my $wrapped = __PACKAGE__->wrap_sub($sub, $types);
+    Sub::Util::set_subname($subname, $wrapped);
+    Sub::Util::set_prototype($prototype, $wrapped) if $prototype;
 
-        Sub::Util::set_subname($subname, $wrapped);
-        Sub::Util::set_prototype($prototype, $wrapped) if $prototype;
-        _set_parameters_info($pinfo, $wrapped) if $pinfo;
-        {
-            no warnings qw(misc);
-            attributes::->import($pkg, $wrapped, @attr) if @attr;
-        }
-        _register_return_info($wrapped, $types);
-
-        no strict qw(refs);
-        no warnings qw(redefine);
-        *{$subname} = $wrapped;
+    if ($pinfo) {
+        _delete_parameters_info($pkey);
+        _set_parameters_info($pinfo, $wrapped);
     }
+
+    {
+        no warnings qw(misc);
+        attributes::->import($pkg, $wrapped, @attr) if @attr;
+    }
+    _register_return_info($wrapped, $types);
+
+    no strict qw(refs);
+    no warnings qw(redefine);
+    *{$subname} = $wrapped;
 }
 
 1;
@@ -248,10 +267,19 @@ This module supports all perl versions starting from v5.14.
 
 =head3 no_check
 
-you can switch off type check:
+You can switch off type check.
+If you change globally, use C<<$ENV{FUNCTION_RETURN_NO_CHECK}>>:
+
+    BEGIN {
+        $ENV{FUNCTION_RETURN_NO_CHECK} = 1;
+    }
+    use Function::Return;
+    sub foo :Return(Int) { 3.14 }
+    foo(); # NO ERROR!
+
+And If you want to switch by a package, it is better to use the no_check option:
 
     use Function::Return no_check => 1;
-
     sub foo :Return(Int) { 3.14 }
     foo(); # NO ERROR!
 
